@@ -8,14 +8,16 @@ SPDX-License-Identifier: LGPL-2.0-or-later
 #define MARKER_H
 
 #include <QList>
-#include "diff2_export.h"
+#include "komparediff2_export.h"
 
 namespace Diff2 {
 
 /**
+ * @class Marker marker.h <KompareDiff2/Marker>
+ *
  * A Marker.
  */
-class DIFF2_EXPORT Marker
+class KOMPAREDIFF2_EXPORT Marker
 {
 public:
     enum Type { Start = 0, End = 1 };
